# Change Log

## 0.2.1

- when you press play on a song when another song is already playing, it will be queued to play next.

## 0.2.0

- Use Starlette (ASGI) instead of bottle as a web framework
- Use asycio version of MPD client
- Highlight row when added to queue
- Display file type and audio details

## 0.1.8

- Get album art embedded in audio file in preference of image in folder
- Fix error handling bugs

## 0.1.7

- Initial release
